@@ -1,3 +1,7 @@
+class NoSpecsForVariable(Exception):
+    """Raise when attempting to access specs of an unknown variable in template."""
+
+
 class MalformedTemplate(Exception):
     """Raise when yaml template does not meet requirements."""
 
